"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("../util/compatibility");
const redux_1 = require("redux");
const store_1 = __importDefault(require("../store"));
const actions = __importStar(require("../store/actions"));
const defaultState_1 = __importDefault(require("../store/defaultState"));
const validate_1 = require("../util/validate");
const embedAPI_1 = __importDefault(require("./embedAPI"));
const messages_1 = __importDefault(require("./messages"));
const renderer_1 = __importDefault(require("./renderer"));
const util_1 = require("./util");
class Crate extends embedAPI_1.default {
    /**
     * Instantiate a new Crate instant
     * @param userOptions The options to use
     */
    constructor(userOptions) {
        super();
        this.options = util_1.observeOptions({
            server: '299881420891881473',
            channel: null,
            location: ['bottom', 'right'],
            color: '#5865f2',
            glyph: ['', ''],
            css: '',
            notifications: true,
            dmNotifications: true,
            indicator: true,
            timeout: 10000,
            shard: 'https://e.widgetbot.io',
            defer: false
        }, this.setOptions.bind(this));
        const options = this.setOptions(userOptions);
        this.store = redux_1.createStore(store_1.default, defaultState_1.default(options.get()), util_1.enhancer);
        this.forceUpdate();
        this.addEventListeners();
        // Add default window.crate reference
        if (window && !window.crate) {
            ;
            window.crate = this;
        }
    }
    /**
     * Force updates the React component
     */
    forceUpdate() {
        const { node, store } = this;
        const onAPI = api => {
            this.api = api;
            this.emit = (...args) => api.emit(...args);
            this.on = (...args) => api.on(...args);
        };
        renderer_1.default({ node, store, onAPI });
    }
    /**
     * Adds the event listeners for the embed-api transport
     */
    addEventListeners() {
        this.forceUpdate();
        const { api } = this;
        if (!api)
            throw new Error(messages_1.default.EMBED_API_INVOCATION);
        let guestID;
        const navigate = (channelId) => {
        };
        api.on('signIn', user => {
            guestID = 'id' in user ? user.id : user._id;
        });
        api.on('message', ({ channel, message }) => {
            if (!this.options.notifications || !message.content || message.author.id === guestID)
                return;
            this.notify({
                id: message.id,
                content: `${message.author.name}${channel.id !== this.options.channel ? ` in #${channel.name}` : ''}: ${message.content}`,
                avatar: message.author.avatarUrl,
                onClick: () => this.navigate(message.channelId)
            });
        });
        api.on('messageDelete', ({ id }) => {
            this.store.dispatch(actions.deleteMessage({ id, decrement: true }));
        });
        api.on('directMessage', ({ message }) => {
            if (!this.options.dmNotifications || !message.content || message.author.id === guestID)
                return;
            this.notify({
                id: message.id,
                content: `${message.author.name}: ${message.content}`,
                avatar: message.author.avatarUrl,
                onClick: () => this.navigate(message.channelId)
            });
        });
        api.on('unreadCountUpdate', ({ count }) => {
            this.store.dispatch(actions.updateUnreadCount(count));
        });
    }
    /*********   Public Methods   *********/
    /**
     * Updates the options by merging a new options object
     * @param options The new options object
     */
    setOptions(options) {
        this.options.set(Object.assign(Object.assign({}, this.options.get()), options));
        if (this.store) {
            this.store.dispatch(actions.updateOptions(options));
        }
        return this.options;
    }
    /**
     * Toggles the widget open / closed
     */
    toggle(open) {
        this.store.dispatch(actions.toggle(open));
    }
    /**
     * Notifies a message to the user
     */
    notify(content) {
        const props = typeof content === 'string' ? { content } : content;
        const data = Object.assign({ timeout: this.options.timeout, id: `${Math.random()}${+new Date()}`, content: props.content }, props);
        this.store.dispatch(actions.message(data));
        const hide = () => this.store.dispatch(actions.deleteMessage({ id: data.id }));
        // Hide the message after timeout
        if (data.timeout)
            setTimeout(hide, Number(data.timeout));
        return { hide };
    }
    navigate(channelId) {
        this.store.dispatch(actions.toggle(true));
        this.emit('navigate', {
            guild: this.options.server,
            channel: channelId,
        });
    }
    /**
     * Un-hides the crate button
     */
    show() {
        this.store.dispatch(actions.toggleVisibility(true));
    }
    /**
     * Hides the crate button
     */
    hide() {
        this.store.dispatch(actions.toggleVisibility(false));
    }
}
__decorate([
    validate_1.validate,
    __param(0, validate_1.is.options)
], Crate.prototype, "setOptions", null);
exports.default = Crate;
//# sourceMappingURL=index.js.map